@@ -157,7 +157,7 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
     }
 
     URL uri (str);
-    if (ActorAgent::Data != type && mime.isEmpty () && uri.isLocalFile ()) {
+    if (mime.isEmpty () && uri.isLocalFile ()) {
         mime = MimeType::findByURL (uri);
         if (mrl)
             mrl->mimetype = mime;
@@ -165,7 +165,7 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
     if (!mime.isEmpty ())
         maybe_playlist = isPlayListMime (mime);
 
-    if (ActorAgent::Data != type && mrl) {
+    if (mrl) {
         if (mime.isEmpty ()) {
             for (Node *p = mrl->parentNode (); p; p = p->parentNode ()) {
                 Mrl *m = p->mrl ();
@@ -220,7 +220,7 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
 }
 
 KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
-    TextStream textstream (data);
+    TextStream textstream (&data);
     String line;
     NodePtr cur_elm = node;
     do {
@@ -373,12 +373,8 @@ KDE_NO_EXPORT void MediaInfo::create () {
 }
 
 KDE_NO_EXPORT void MediaInfo::ready () {
-    if (ActorAgent::Data != type)
-        create ();
-    if (ActorAgent::Data == type)
-        node->message (MsgMediaReady);
-    else
-        node->document()->post (new Posting (node, node, MsgMediaReady));
+    create ();
+    node->document()->post (new Posting (node, node, MsgMediaReady));
 }
 
 static bool validDataFormat (ActorAgent::ActorType type, const ByteArray &ba) {
@@ -407,7 +403,7 @@ KDE_NO_EXPORT void MediaInfo::jobResult (IOJob *jb) {
     if (jb->error () || (data.size () < 512 && !validDataFormat (type, data)))
         data.resize (0);
     job = 0L; // signal KIO::IOJob::result deletes itself
-    if (ActorAgent::Data != type && mime.isEmpty ()) {
+    if (mime.isEmpty ()) {
         mime = jb->contentType ();
         if (node->mrl ()) {
             node->mrl ()->mimetype = mime;
@@ -444,7 +440,6 @@ KDE_NO_EXPORT void MediaInfo::redirected (IOJob *, const String &url) {
 AudioVideoActor::AudioVideoActor (ActorAgent *manager, Node *node)
  : Actor (manager, node),
    ignore_pause (false) {
-    debugLog() << "AudioVideoActor::AudioVideoActor" << endl;
 }
 
 AudioVideoActor::~AudioVideoActor () {
@@ -747,13 +742,12 @@ bool ImageActor::isEmpty () const {
 
 //------------------------%<----------------------------------------------------
 
-static int default_font_size = 14;
+static int default_font_size = 11;
 
 TextActor::TextActor (ActorAgent *manager, Node *node, const ByteArray &ba)
  : Actor (manager, node) {
     if (!ba.isEmpty ())
         text = String (ba.data (), ba.size ());
-    debugLog() << "TextActor::ready " << ba.size () << " " << text << endl;
 }
 
 TextActor::~TextActor () {
