@@ -40,7 +40,7 @@ class Surface;
  */
 class KMPLAYER_EXPORT ActorAgent {
 public:
-    enum ActorType { Any, Audio, AudioVideo, Image, Text, Data };
+    enum ActorType { Any, Audio, AudioVideo, Image, Text };
     //typedef QValueList <Actor *> MediaList;
 
     ActorAgent (Control *ctrl);
