@@ -171,17 +171,17 @@ static void _app_setup_window (GtkWidget * w, Application *app) {
 void app_full_screen (Application *app) {
     if (!app->fullscreen) {
         if (!app->window_fullscreen) {
-            HildonWindow *win = HILDON_WINDOW (hildon_window_new ());
+            HildonWindow *win = HILDON_WINDOW (hildon_stackable_window_new ());
             app->window_fullscreen = GTK_WINDOW (win);
             app->view_area_fullscreen = gtk_drawing_area_new ();
             gtk_container_add (GTK_CONTAINER (win),
                     app->view_area_fullscreen);
             _app_setup_window (app->view_area_fullscreen, app);
             hildon_program_add_window (HILDON_PROGRAM (app->program), win);
-            g_signal_connect (G_OBJECT (win), "map-event",
+            /*g_signal_connect (G_OBJECT (win), "map-event",
                     GTK_SIGNAL_FUNC (cbViewAreaFullscreenMapped), app);
             g_signal_connect (G_OBJECT (win), "unmap",
-                    GTK_SIGNAL_FUNC (cbViewAreaFullscreenUnmapped), app);
+                    GTK_SIGNAL_FUNC (cbViewAreaFullscreenUnmapped), app);*/
             g_signal_connect (G_OBJECT (win), "destroy",
                     GTK_SIGNAL_FUNC (cb_fullscreen_destoyed), app);
             g_signal_connect (G_OBJECT (win), "key-press-event",
@@ -189,6 +189,7 @@ void app_full_screen (Application *app) {
         }
         app->fullscreen = true;
         gtk_widget_show_all (GTK_WIDGET (app->window_fullscreen));
+        cbViewAreaFullscreenMapped (GTK_WIDGET (app->window_fullscreen), NULL, app);
         app_update_screen_blanking (app);
     }
 }
@@ -196,7 +197,8 @@ void app_full_screen (Application *app) {
 void app_normal_screen (Application *app) {
     if (app->fullscreen) {
         app->fullscreen = false;
-        gtk_widget_hide (GTK_WIDGET (app->window_fullscreen));
+        hildon_window_stack_pop_1 (hildon_window_stack_get_default ());
+        cbViewAreaFullscreenUnmapped (GTK_WIDGET (app->window_fullscreen), app);
     }
     app_update_screen_blanking (app);
 }
@@ -315,10 +317,10 @@ static void create_toolbar (Application * app) {
     app->tb_stop = gtk_tool_button_new_from_stock (GTK_STOCK_MEDIA_STOP);
     app->tb_save = gtk_tool_button_new_from_stock (GTK_STOCK_SAVE);
     tb_go = gtk_tool_button_new (gtk_image_new_from_icon_name(
-                "qgn_toolb_browser_gobutton", HILDON_ICON_SIZE_TOOLBAR), NULL);
+                "widgets_tickmark_grid", HILDON_ICON_SIZE_TOOLBAR), NULL);
     app->tb_item_playlist_commit = GTK_WIDGET (gtk_tool_button_new (
                 gtk_image_new_from_icon_name(
-                    "qgn_toolb_gene_refresh", HILDON_ICON_SIZE_TOOLBAR), NULL));
+                    "general_refresh", HILDON_ICON_SIZE_TOOLBAR), NULL));
     /* Create toolbar combobox item */
     app->tb_location = gtk_tool_item_new();
     app->tb_progress = gtk_tool_item_new();
@@ -634,7 +636,7 @@ int main (int argc, char* argv[]) {
         return 1;
     }*/
     /* Create HildonAppView and set it to HildonApp */
-    main_window = HILDON_WINDOW (hildon_window_new ());
+    main_window = HILDON_WINDOW (hildon_stackable_window_new ());
     app->window = GTK_WINDOW (main_window);
 
     /* Add example label to appview */
