@@ -157,7 +157,7 @@ gchar *app_file_chooser (Application *app, const char *path, GtkFileChooserActio
 void app_store_save_directory (Application *app, gchar *path);
 
 void openFile (Application *app, const gchar *path) MAEMO_NO_EXPORT;
-const char *saveFile (void *ctr, const gchar *path) MAEMO_NO_EXPORT;
+void saveFile (Application *app, bool as_xml) MAEMO_NO_EXPORT;
 void newFile (Application *app) MAEMO_NO_EXPORT;
 
 /*#define KMPLAYER_DEBUG*/
