@@ -21,8 +21,6 @@
 #ifndef _KMPLAYER_ASX_H_
 #define _KMPLAYER_ASX_H_
 
-#include <qstring.h>
-
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -42,23 +40,24 @@ const short id_node_duration = 408;
 /**
  * '<ASX>' tag
  */
-class Asx : public Mrl {
+class KMPLAYER_NO_EXPORT Asx : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Asx (NodePtr & d) : Mrl (d, id_node_asx) {}
-    NodePtr childFromTag (const QString & tag);
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "ASX"; }
-    bool expose () const { return !pretty_name.isEmpty (); }
+    bool expose () const { return !title.isEmpty (); }
     PlayType playType ();
 };
 
 /**
  * Entry tag as found in ASX for playlist item
  */
-class KMPLAYER_NO_EXPORT Entry : public Mrl {
+class Entry : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Entry (NodePtr & d)
-        : Mrl (d, id_node_entry), ref_child_count (0) {}
-    NodePtr childFromTag (const QString & tag);
+        : Mrl (d, id_node_entry), duration_timer (NULL), ref_child_count (0) {}
+    Node *childFromTag (const String & tag);
+    void message (MessageType msg, void *content=NULL);
     KDE_NO_EXPORT const char * nodeName () const { return "Entry"; }
     /**
      * False, but since we might have a 'base' child, we can have a rel. src
@@ -67,16 +66,18 @@ public:
     void activate ();
     void deactivate ();
     bool expose () const;
+
+    Command *duration_timer;
     int ref_child_count;
 };
 
 /**
  * Ref tag as found in ASX for URL item in playlist item
  */
-class KMPLAYER_NO_EXPORT Ref : public Mrl {
+class Ref : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Ref (NodePtr & d) : Mrl (d, id_node_ref) {}
-    //NodePtr childFromTag (const QString & tag);
+    //Node *childFromTag (const String & tag);
     void opened ();
     KDE_NO_EXPORT const char * nodeName () const { return "Ref"; }
     bool expose () const;
@@ -85,10 +86,10 @@ public:
 /**
  * EntryRef tag as found in ASX for shortcut of Entry plus Ref playlist item
  */
-class KMPLAYER_NO_EXPORT EntryRef : public Mrl {
+class EntryRef : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT EntryRef (NodePtr & d) : Mrl (d, id_node_entryref) {}
-    //NodePtr childFromTag (const QString & tag);
+    //Node *childFromTag (const String & tag);
     void opened ();
     KDE_NO_EXPORT const char * nodeName () const { return "EntryRef"; }
 };
