@@ -51,10 +51,12 @@ public:
         { perc_size *= f; abs_size *= f; return *this; }
     Single size (Single relative_to = 100) const;
     bool isSet () const { return isset; }
+    String toString () const;
 private:
     Single perc_size;
     Single abs_size;
     bool isset;
+    bool has_percentage;
 };
 
 /**
@@ -232,6 +234,8 @@ const short id_node_smil_text = 125;
 const short id_node_text_styling = 126;
 const short id_node_set = 132;
 const short id_node_animate = 133;
+const short id_node_animate_color = 134;
+const short id_node_animate_motion = 135;
 const short id_node_title = 140;
 const short id_node_param = 141;
 const short id_node_meta = 142;
@@ -243,7 +247,7 @@ const short id_node_anchor = 150;
 const short id_node_area = 151;
 const short id_node_first = id_node_smil;
 const short id_node_first_timed_mrl = id_node_body;
-const short id_node_last_timed_mrl = id_node_animate;
+const short id_node_last_timed_mrl = id_node_animate_motion;
 const short id_node_first_mediatype = id_node_img;
 const short id_node_last_mediatype = id_node_brush;
 const short id_node_first_group = id_node_body;
@@ -331,6 +335,9 @@ public:
     unsigned int background_color;
     int bg_opacity;
     String background_image;
+    enum BackgroundRepeat {
+        BgRepeat, BgRepeatX, BgRepeatY, BgNoRepeat, BgInherit
+    } bg_repeat;
     ShowBackground show_background;
     Fit fit;
     ConnectionList m_AttachedMediaTypes;   // active attached mediatypes
@@ -663,6 +670,7 @@ protected:
     ConnectionLink region_paint;           // attached region needs painting
     ConnectionLink region_attach;          // attached to region
     ConnectionLink document_postponed;     // pause audio/video accordantly
+    ConnectionLink transition_updater;
     PostponePtr postpone_lock;
 };
 
@@ -771,8 +779,8 @@ public:
     virtual void *role (RoleType msg, void *content=NULL);
     Runtime *runtime;
 protected:
-    void restoreModification ();
-    NodePtr targetElement ();
+    virtual void restoreModification ();
+    Node *targetElement ();
     AnimateGroup (NodePtr &d, short _id);
     NodePtrW target_element;
     TrieString changed_attribute;
@@ -789,43 +797,15 @@ public:
     PlayType playType () { return play_type_none; }
 };
 
-class KMPLAYER_NO_EXPORT Animate : public AnimateGroup {
-public:
-    KDE_NO_CDTOR_EXPORT Animate (NodePtr &doc);
-    virtual void init ();
-    virtual void begin ();
-    virtual void finish ();
-    virtual void deactivate ();
-    virtual void parseParam (const TrieString & name, const String & value);
-    virtual void message (MessageType msg, void *content=NULL);
-    virtual void accept (Visitor *v) { v->visit (this); }
-    KDE_NO_EXPORT const char * nodeName () const { return "animate"; }
-    PlayType playType () { return play_type_none; }
-
-    Command *anim_timer;
-private:
-    void applyStep ();
-    bool timerTick();
-
-    enum { acc_none, acc_sum } accumulate;
-    enum { add_replace, add_sum } additive;
-    int change_by;
-    enum { calc_discrete, calc_linear, calc_paced, calc_spline } calcMode;
-    String change_from;
-    StringList change_values;
-    int steps;
-    float change_delta, change_to_val, change_from_val;
-    String change_from_unit;
-};
-
-class KMPLAYER_NO_EXPORT AnimateMotion : public AnimateGroup {
+class KMPLAYER_NO_EXPORT AnimateBase : public AnimateGroup {
 public:
     struct Point2D {
         float x;
         float y;
     };
-    AnimateMotion (NodePtr & d);
-    ~AnimateMotion ();
+    AnimateBase (NodePtr &d, short id);
+    ~AnimateBase ();
+
     virtual void init ();
     virtual void begin ();
     virtual void finish ();
@@ -833,38 +813,111 @@ public:
     virtual void parseParam (const TrieString & name, const String & value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void accept (Visitor *v) { v->visit (this); }
-    KDE_NO_EXPORT const char * nodeName () const { return "animateMotion"; }
     PlayType playType () { return play_type_none; }
 
     Command *anim_timer;
-private:
-    bool timerTick (unsigned int cur_time);
-    bool checkTarget (Node *n);
+protected:
+    virtual bool timerTick (unsigned int cur_time) = 0;
+    virtual void applyStep () = 0;
+
     bool setInterval ();
-    void applyStep ();
-    bool getCoordinates (const String &coord, SizeType &x, SizeType &y);
+
     enum { acc_none, acc_sum } accumulate;
     enum { add_replace, add_sum } additive;
     enum { calc_discrete, calc_linear, calc_paced, calc_spline } calcMode;
     String change_from;
     String change_by;
     StringList values;
+    ConnectionLink change_updater;
     float *keytimes;
     Point2D *spline_table;
-    int keytime_count;
     StringList splines;
     float control_point[4];
+    unsigned int keytime_count;
     unsigned int keytime_steps;
     unsigned int interval;
     unsigned int interval_start_time;
     unsigned int interval_end_time;
+};
+
+class KMPLAYER_NO_EXPORT Animate : public AnimateBase {
+public:
+    Animate (NodePtr &doc);
+    virtual void init ();
+    virtual void begin ();
+    virtual void finish ();
+    virtual void deactivate ();
+    //virtual void accept (Visitor *v) { v->visit (this); }
+    KDE_NO_EXPORT const char * nodeName () const { return "animate"; }
+
+private:
+    virtual bool timerTick (unsigned int cur_time);
+    virtual void applyStep ();
+
+    void cleanUp ();
+
+    int num_count;
+    SizeType *begin_;
+    SizeType *cur;
+    SizeType *delta;
+    SizeType *end;
+};
+
+class KMPLAYER_NO_EXPORT AnimateMotion : public AnimateBase {
+public:
+    AnimateMotion (NodePtr &d) : AnimateBase (d, id_node_animate_motion) {}
+
+    virtual void init ();
+    virtual void begin ();
+    virtual void finish ();
+    //virtual void accept (Visitor *v) { v->visit (this); }
+    KDE_NO_EXPORT const char * nodeName () const { return "animateMotion"; }
+
+private:
+    virtual void restoreModification ();
+    virtual bool timerTick (unsigned int cur_time);
+    virtual void applyStep ();
+
+    CalculatedSizer old_sizes;
     SizeType begin_x, begin_y;
     SizeType cur_x, cur_y;
     SizeType delta_x, delta_y;
     SizeType end_x, end_y;
 };
 
-// TODO animateColor transitionFilter
+class KMPLAYER_NO_EXPORT AnimateColor : public AnimateBase {
+public:
+    struct Channels {
+        short blue;
+        short green;
+        short red;
+        short alpha;
+        unsigned int argb ();
+        void clear ();
+        Channels &operator *= (const float f);
+        Channels &operator += (const Channels &c);
+        Channels &operator -= (const Channels &c);
+    };
+
+    AnimateColor (NodePtr &d) : AnimateBase (d, id_node_animate_color) {}
+
+    virtual void init ();
+    virtual void begin ();
+    virtual void finish ();
+    //virtual void accept (Visitor *v) { v->visit (this); }
+    KDE_NO_EXPORT const char * nodeName () const { return "animateColor"; }
+
+private:
+    virtual bool timerTick (unsigned int cur_time);
+    virtual void applyStep ();
+
+    Channels begin_c;
+    Channels cur_c;
+    Channels delta_c;
+    Channels end_c;
+};
+
+// TODO transitionFilter
 
 class KMPLAYER_NO_EXPORT Param : public Element {
 public:
