@@ -90,6 +90,11 @@ void *SourceDocument::role (RoleType msg, void *data) {
     case RoleChildDisplay:
         return VIEWAREA(m_control->m_app)->getSurface ((Mrl *) data);
 
+    case RoleReceivers:
+        if (MsgSurfaceUpdate == (MessageType) (long) data)
+            return VIEWAREA(m_control->m_app)->updaters ();
+
+        // fall through
     default:
         break;
     }
@@ -126,7 +131,12 @@ void Control::init () {
 
     use_xvideo = !glob ("/usr/lib/libXv.so*", GLOB_ERR|GLOB_NOSORT, 0, &gt);
     globfree (&gt);
-    media_server = new OssoMediaServer (this, m_app->osso_context, use_xvideo);
+   //media_server = new OssoMediaServer (this, m_app->osso_context, use_xvideo);
+    MPlayer *gst = new MPlayer (this, false);
+    gst->setPlayer ("kgstplayer");
+    gst->setAudioDriver ("pulse");
+    gst->setVideoDriver ("xv");
+    media_server = gst;
     mplayer = new MPlayer (this, use_xvideo);
 #ifdef __ARMEL__
     npp = new NpPlayer (this);
@@ -146,7 +156,7 @@ void Control::init () {
     addTree (m_app, 0L, //gdk_pixbuf_new_from_xpm_data((const char**)www_xpm));
             gdk_pixbuf_scale_simple (
                     gtk_icon_theme_load_icon (icon_theme,
-                        "qgn_grid_tasknavigator_web", 26,
+                        "general_web", 26,
                         (GtkIconLookupFlags)0, 0L),
                     26, 26, GDK_INTERP_BILINEAR));
 
@@ -187,7 +197,7 @@ void Control::init () {
             expl->path = str;
             addTree (m_app, expl,
                     gtk_icon_theme_load_icon(icon_theme,
-                      "qgn_list_gene_playlist", 26, (GtkIconLookupFlags)0, 0L));
+                      "filemanager_playlist", 26, (GtkIconLookupFlags)0, 0L));
         }
         gconf_entry_free (entry);
     }
@@ -208,7 +218,7 @@ void Control::init () {
     rcdoc->path = tmp;
     m_app->recents_tree_id = addTree (m_app, rcdoc,
             gtk_icon_theme_load_icon(icon_theme,
-                "qgn_list_gene_url_history", 26, (GtkIconLookupFlags)0, 0L));
+                "general_clock", 26, (GtkIconLookupFlags)0, 0L));
 
     String sf = m_config->readEntry (GCONF_KEY_SAVE_FOLDER, String());
     if (!sf.isEmpty ())
@@ -573,14 +583,6 @@ void Control::openUrl (const URL &url, const String &, const String & /*srv*/) {
     //errorMsg ("Open for target and mimetype is not supported");
 }
 
-void Control::addRepaintUpdater (Node *node) {
-    viewArea ()->addUpdater (node);
-}
-
-void Control::removeRepaintUpdater (Node *node) {
-    viewArea ()->removeUpdater (node);
-}
-
 void Control::enableRepaintUpdaters (bool enable, unsigned int off_time) {
     viewArea ()->enableUpdaters (enable, off_time);
 }
