@@ -87,8 +87,6 @@ public:
     void bitRates (int & prefered, int & maximal);
     void setTimeout (int ms);
     void openUrl (const URL &, const String &target, const String &srv);
-    void addRepaintUpdater (Node *node);
-    void removeRepaintUpdater (Node *node);
     void enableRepaintUpdaters (bool enable, unsigned int off_time);
 
     void setProcess (Process * p) { m_process = p; }
