@@ -120,6 +120,7 @@ bool ConnectionLink::connect (Node *send, MessageType msg, Node *rec) {
             list->link_first = connection;
         list->link_last = connection;
     }
+    return list;
 }
 
 void ConnectionLink::disconnect () const {
@@ -412,7 +413,7 @@ void getOuterXML (const Node *p, TextStream & out, int depth, bool inter) {
         const Element *e = static_cast <const Element *> (p);
         String indent (String ().fill (Char (' '), depth));
         out << indent << char_lt << XMLStringlet (e->nodeName ());
-        for (Attribute *a = e->attributes()->first(); a; a = a->nextSibling())
+        for (Attribute *a = e->attributes().first(); a; a = a->nextSibling())
             out << " " << XMLStringlet (a->name ().toString ()) <<
                 "=\"" << XMLStringlet (a->value ()) << "\"";
         if (e->hasChildNodes ()) {
@@ -460,7 +461,7 @@ void Node::message (MessageType msg, void *content) {
     case MsgChildFinished: {
         Posting *post = (Posting *) content;
         if (unfinished ()) {
-            if (post->source->state == state_finished)
+            if (post->source && post->source->state == state_finished)
                 post->source->deactivate ();
             if (post->source && post->source->nextSibling ())
                 post->source->nextSibling ()->activate ();
@@ -545,7 +546,7 @@ KDE_NO_EXPORT void ElementPrivate::clear () {
 }
 
 Element::Element (NodePtr & d, short id)
-    : Node (d, id), m_attributes (new AttributeList), d (new ElementPrivate) {}
+    : Node (d, id), d (new ElementPrivate) {}
 
 Element::~Element () {
     delete d;
@@ -603,20 +604,20 @@ void Element::resetParam (const TrieString &name, int mid) {
 }
 
 void Element::setAttribute (const TrieString & name, const String & value) {
-    for (Attribute *a = m_attributes->first (); a; a = a->nextSibling ())
+    for (Attribute *a = m_attributes.first (); a; a = a->nextSibling ())
         if (name == a->name ()) {
             if (value.isNull ())
-                m_attributes->remove (a);
+                m_attributes.remove (a);
             else
                 a->setValue (value);
             return;
         }
     if (!value.isNull ())
-        m_attributes->append (new Attribute (name, value));
+        m_attributes.append (new Attribute (TrieString (), name, value));
 }
 
 String Element::getAttribute (const TrieString & name) {
-    for (Attribute *a = m_attributes->first (); a; a = a->nextSibling ())
+    for (Attribute *a = m_attributes.first (); a; a = a->nextSibling ())
         if (name == a->name ())
             return a->value ();
     return String ();
@@ -624,7 +625,7 @@ String Element::getAttribute (const TrieString & name) {
 
 void Element::init () {
     d->clear();
-    for (Attribute *a = attributes ()->first (); a; a = a->nextSibling ())
+    for (Attribute *a = attributes ().first (); a; a = a->nextSibling ())
         parseParam (a->name (), a->value ());
 }
 
@@ -634,12 +635,12 @@ void Element::reset () {
 }
 
 void Element::clear () {
-    m_attributes = new AttributeList; // remove attributes
+    m_attributes = AttributeList (); // remove attributes
     d->clear();
     Node::clear ();
 }
 
-void Element::setAttributes (AttributeListPtr attrs) {
+void Element::setAttributes (const AttributeList &attrs) {
     m_attributes = attrs;
 }
 
@@ -649,8 +650,8 @@ void Element::accept (Visitor * v) {
 
 //-----------------------------------------------------------------------------
 
-Attribute::Attribute (const TrieString & n, const String & v)
-  : m_name (n), m_value (v) {}
+Attribute::Attribute (const TrieString &ns, const TrieString &n, const String &v)
+  : m_namespace (ns), m_name (n), m_value (v) {}
 
 void Attribute::setName (const TrieString & n) {
     m_name = n;
@@ -1407,7 +1408,7 @@ class KMPLAYER_NO_EXPORT DocumentBuilder {
 public:
     DocumentBuilder (NodePtr d, bool set_opener);
     ~DocumentBuilder () {}
-    bool startTag (const String & tag, AttributeListPtr attr);
+    bool startTag (const String & tag, const AttributeList &attr);
     bool endTag (const String & tag);
     bool characterData (const String &data, bool append_only=false);
     bool cdataData (const String & data);
@@ -1430,7 +1431,7 @@ DocumentBuilder::DocumentBuilder (NodePtr d, bool set_opener)
 #endif
 {}
 
-bool DocumentBuilder::startTag(const String &tag, AttributeListPtr attr) {
+bool DocumentBuilder::startTag(const String &tag, const AttributeList &attr) {
     if (m_ignore_depth) {
         m_ignore_depth++;
         //kdDebug () << "Warning: ignored tag " << tag.latin1 () << " ignore depth = " << m_ignore_depth << endl;
@@ -1547,10 +1548,13 @@ void DocumentBuilder::cdataEnd () {
 
 static void startTag (void *data, const char * tag, const char **attr) {
     DocumentBuilder * builder = static_cast <DocumentBuilder *> (data);
-    AttributeListPtr attributes = new AttributeList;
+    AttributeList attributes;
     if (attr && attr [0]) {
         for (int i = 0; attr[i]; i += 2)
-            attributes->append (new Attribute (String::fromUtf8 (attr [i]), String::fromUtf8 (attr [i+1])));
+            attributes.append (new Attribute (
+                        TrieString(),
+                        String::fromUtf8 (attr [i]),
+                        String::fromUtf8 (attr [i+1])));
     }
     builder->startTag (String::fromUtf8 (tag), attributes);
 }
@@ -1614,8 +1618,8 @@ namespace {
 class SimpleSAXParser {
     enum Token { tok_empty, tok_text, tok_white_space, tok_angle_open,
         tok_equal, tok_double_quote, tok_single_quote, tok_angle_close,
-        tok_slash, tok_exclamation, tok_amp, tok_hash, tok_semi_colon,
-        tok_question_mark, tok_cdata_start };
+        tok_slash, tok_exclamation, tok_amp, tok_hash, tok_colon,
+        tok_semi_colon, tok_question_mark, tok_cdata_start };
 public:
     struct TokenInfo {
         TokenInfo () : token (tok_empty) {}
@@ -1626,7 +1630,7 @@ public:
         SharedPtr <TokenInfo> next;
     };
     typedef SharedPtr <TokenInfo> TokenInfoPtr;
-    SimpleSAXParser (DocumentBuilder & b) : builder (b), position (0), m_attributes (new AttributeList), equal_seen (false), in_dbl_quote (false), in_sngl_quote (false), have_error (false), no_entitity_look_ahead (false), have_next_char (false) {}
+    SimpleSAXParser (DocumentBuilder & b) : builder (b), position (0), equal_seen (false), in_dbl_quote (false), in_sngl_quote (false), have_error (false), no_entitity_look_ahead (false), have_next_char (false) {}
     ~SimpleSAXParser ();
     bool parse (TextStream & d);
 private:
@@ -1647,8 +1651,8 @@ private:
     TokenInfoPtr next_token, token, prev_token;
     // for element reading
     String tagname;
-    AttributeListPtr m_attributes;
-    String attr_name, attr_value;
+    AttributeList m_attributes;
+    String attr_namespace, attr_name, attr_value;
     String cdata;
     bool equal_seen;
     bool in_dbl_quote;
@@ -1728,7 +1732,8 @@ void SimpleSAXParser::push () {
 
 void SimpleSAXParser::push_attribute () {
     //kdDebug () << "attribute " << attr_name.latin1 () << "=" << attr_value.latin1 () << endl;
-    m_attributes->append (new Attribute (attr_name, attr_value));
+    m_attributes.append(new Attribute (attr_namespace, attr_name, attr_value));
+    attr_namespace.clear ();
     attr_name.truncate (0);
     attr_value.truncate (0);
     equal_seen = in_sngl_quote = in_dbl_quote = false;
@@ -1771,6 +1776,10 @@ bool SimpleSAXParser::nextToken () {
             } else if (next_char == char_gt) {
                 push ();
                 next_token->token = tok_angle_close;
+            } else if (InAttributes == m_state->state &&
+                    next_char == Char (':')) {
+                push ();
+                next_token->token = tok_colon;
             } else if (next_char == char_semi) {
                 push ();
                 next_token->token = tok_semi_colon;
@@ -1907,6 +1916,13 @@ bool SimpleSAXParser::readAttributes () {
                 in_sngl_quote = true;
             else
                 attr_value += token->string;
+        } else if (token->token == tok_colon) {
+            if (equal_seen) {
+                attr_value += token->string;
+            } else {
+                attr_namespace = attr_name;
+                attr_name.clear();
+            }
         } else if (token->token == tok_double_quote) {
             if (!equal_seen)
                 attr_name += token->string; // hmm
@@ -2116,7 +2132,7 @@ bool SimpleSAXParser::parse (TextStream & d) {
                     if (token->token == tok_angle_open) {
                         attr_name.truncate (0);
                         attr_value.truncate (0);
-                        m_attributes = new AttributeList;
+                        m_attributes = AttributeList ();
                         equal_seen = in_sngl_quote = in_dbl_quote = false;
                         m_state = new StateInfo (InTag, m_state);
                         ok = readTag ();
