@@ -103,10 +103,10 @@ private:
  }
 
 /*
- * A shareable double linked list of ListNodeBase<T> nodes
+ * A double linked list of ListNodeBase<T> nodes
  */
 template <class T>
-class KMPLAYER_EXPORT List : public Item <List <T> > {
+class KMPLAYER_EXPORT List {
 public:
     List () {}
     List (typename Item<T>::SharedType f, typename Item<T>::SharedType l)
@@ -187,13 +187,15 @@ protected:
 class KMPLAYER_EXPORT Attribute : public ListNodeBase <Attribute> {
 public:
     KDE_NO_CDTOR_EXPORT Attribute () {}
-    Attribute (const TrieString & n, const String & v);
+    Attribute (const TrieString &ns, const TrieString &n, const String &v);
     KDE_NO_CDTOR_EXPORT ~Attribute () {}
+    TrieString ns () const { return m_namespace; }
     TrieString name () const { return m_name; }
     String value () const { return m_value; }
     void setName (const TrieString &);
     void setValue (const String &);
 protected:
+    TrieString m_namespace;
     TrieString m_name;
     String m_value;
 };
@@ -265,12 +267,7 @@ typedef Item<Node>::WeakType NodePtrW;
 typedef Item<Attribute>::SharedType AttributePtr;
 typedef Item<Attribute>::WeakType AttributePtrW;
 typedef List<Node> NodeList;                 // eg. for Node's children
-typedef Item<NodeList>::SharedType NodeListPtr;
-typedef Item<NodeList>::WeakType NodeListPtrW;
-ITEM_AS_POINTER(KMPlayer::NodeList)
 typedef List<Attribute> AttributeList;       // eg. for Element's attributes
-typedef Item<AttributeList>::SharedType AttributeListPtr;
-ITEM_AS_POINTER(KMPlayer::AttributeList)
 typedef ListNode<NodePtrW> NodeRefItem;      // Node for ref Nodes
 ITEM_AS_POINTER(KMPlayer::NodeRefItem)
 typedef ListNode<NodePtr> NodeStoreItem;   // list stores Nodes
@@ -490,7 +487,7 @@ public:
     void normalize ();
     KDE_NO_EXPORT bool isDocument () const { return m_doc == m_self; }
 
-    KDE_NO_EXPORT NodeListPtr childNodes () const;
+    NodeList childNodes () const;
     void setState (State nstate);
     /*
      * Open tag is found by parser, attributes are set
@@ -530,10 +527,11 @@ const short id_node_svg = 29;
 class KMPLAYER_EXPORT Element : public Node {
 public:
     ~Element ();
-    void setAttributes (AttributeListPtr attrs);
+    void setAttributes (const AttributeList &attrs);
     void setAttribute (const TrieString & name, const String & value);
     String getAttribute (const TrieString & name);
-    KDE_NO_EXPORT AttributeList *attributes () const { return m_attributes.ptr (); }
+    KDE_NO_EXPORT AttributeList &attributes () { return m_attributes; }
+    KDE_NO_EXPORT AttributeList attributes () const { return m_attributes; }
     virtual void init ();
     virtual void reset ();
     virtual void clear ();
@@ -553,7 +551,7 @@ public:
     virtual void parseParam (const TrieString &, const String &) {}
 protected:
     Element (NodePtr & d, short id=0);
-    AttributeListPtr m_attributes;
+    AttributeList m_attributes;
 private:
     ElementPrivate * d;
 };
@@ -656,10 +654,8 @@ public:
      */
     virtual void openUrl (const URL &, const String &tgt, const String &srv)=0;
     /**
-     * Change repaint updaters
+     * Dis/Enable repaint updaters
      */
-    virtual void addRepaintUpdater (Node *node)=0;
-    virtual void removeRepaintUpdater (Node *node)=0;
     virtual void enableRepaintUpdaters (bool enable, unsigned int off_time)=0;
 };
 
@@ -813,6 +809,7 @@ namespace SMIL {
     class Par;
     class Excl;
     class Transition;
+    class AnimateBase;
     class Animate;
     class AnimateMotion;
     class MediaType;
@@ -852,8 +849,7 @@ public:
     virtual void visit (SMIL::Par *);
     virtual void visit (SMIL::Excl *);
     virtual void visit (SMIL::Transition *);
-    virtual void visit (SMIL::Animate *);
-    virtual void visit (SMIL::AnimateMotion *);
+    virtual void visit (SMIL::AnimateBase *);
     virtual void visit (SMIL::PriorityClass *);
     virtual void visit (SMIL::MediaType *);
     virtual void visit (SMIL::ImageMediaType *);
@@ -1063,8 +1059,8 @@ inline void TreeNode<T>::removeChildImpl (typename Item<T>::SharedType c) {
     c->m_parent = 0L;
 }
 
-inline KDE_NO_EXPORT NodeListPtr Node::childNodes () const {
-    return new NodeList (m_first_child, m_last_child);
+inline KDE_NO_EXPORT NodeList Node::childNodes () const {
+    return NodeList (m_first_child, m_last_child);
 }
 
 }  // KMPlayer namespace
