@@ -139,7 +139,7 @@ int populate (GtkTreeStore * tree_store, PlayListData * pld,
     //if (e->active ())
     //    ; //ensureItemVisible (item);
     if (e->isElementNode ()) {
-        Attribute *a = static_cast <Element *> (e)->attributes ()->first ();
+        Attribute *a = static_cast <Element *> (e)->attributes ().first ();
         if (a) {
             m_have_dark_nodes = true;
             if (pld->show_all) {
@@ -192,7 +192,7 @@ static gboolean findNode (PlayListData *pld, GtkTreeModel *model, Node *node, Gt
                     if (!gtk_tree_model_iter_children (model, iter, &piter))
                         return false;
                     if (pld->show_all && n->isElementNode () &&
-                            static_cast<Element*>(n)->attributes()->first() &&
+                            static_cast<Element*>(n)->attributes().first() &&
                             !gtk_tree_model_iter_next (model, iter))
                         return false;
                 } else if (!gtk_tree_model_iter_next (model, iter)) {
@@ -397,10 +397,10 @@ static Node *getNode (PlayListData * pld, GtkTreePath * path) {
     if (pld->show_all) {
         for (int i = 1; node && i < depth; i++) {
             bool has_attrs = (node->isElementNode () &&
-                    static_cast<Element *> (node)->attributes ()->first ());
+                    static_cast<Element *> (node)->attributes ().first ());
             int index = idxs [i] - (has_attrs ? 1 : 0);
             //    g_print ("cb_selection_changed %d->%d\n", idxs [i], index);
-            node = index < 0 ? 0L : node->childNodes ()->item (index);
+            node = index < 0 ? 0L : node->childNodes ().item (index);
         }
     } else {
         for (int i = 1; node && i < depth; i++) {
@@ -657,23 +657,23 @@ GtkWidget * createTreeView (Application * app) {
 
     GtkIconTheme *icon_theme = gtk_icon_theme_get_default();
     folder_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_filesys_video_fldr", 26, (GtkIconLookupFlags)0, 0L);
+            "filemanager_video_folder", 26, (GtkIconLookupFlags)0, 0L);
     auxiliary_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_gene_attacpap", 26, (GtkIconLookupFlags)0, 0L);
+            "general_profile", 26, (GtkIconLookupFlags)0, 0L);
     auxiliary_fld_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_filesys_common_fldr", 26, (GtkIconLookupFlags)0, 0L);
+            "filemanager_document_folder", 26, (GtkIconLookupFlags)0, 0L);
     unknown_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_gene_unknown_file", 26, (GtkIconLookupFlags)0, 0L);
+            "filemanager_nonreadable_file", 26, (GtkIconLookupFlags)0, 0L);
     config_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_cp_soundset", 26, (GtkIconLookupFlags)0, 0L);
+            "general_settings", 26, (GtkIconLookupFlags)0, 0L);
     music_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_musicpl_file", 26, (GtkIconLookupFlags)0, 0L);
+            "general_audio_file", 26, (GtkIconLookupFlags)0, 0L);
     video_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_videopl_file", 26, (GtkIconLookupFlags)0, 0L);
+            "general_video_file", 26, (GtkIconLookupFlags)0, 0L);
     video_link_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_musicpl_file_link", 26, (GtkIconLookupFlags)0, 0L);
+            "imageviewer_favourite", 26, (GtkIconLookupFlags)0, 0L);
     list_pix = gtk_icon_theme_load_icon (icon_theme,
-            "qgn_list_medi", 26, (GtkIconLookupFlags)0, 0L);
+            "filemanager_playlist", 26, (GtkIconLookupFlags)0, 0L);
 
     store = gtk_tree_store_new (3, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT);
     view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
