@@ -387,6 +387,9 @@ void UnixProcess::processExited (GPid pid) {
 MPlayer::MPlayer (ProcessNotify * ctrl, bool xv)
  : Process (ctrl, "mplayer", xv),
    unix_process (this, UnixProcess::StdIn | UnixProcess::StdOut),
+   path ("mplayer"),
+   audio_driver (NULL),
+   video_driver (NULL),
    wait_for_pause (false) {
     m_rect = IRect (434, 60, 342, 260);
 }
@@ -418,27 +421,34 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     }
     request_quit = false;
     outbuf[0] = 0;
-    String cmdline ="mplayer -nofs -slave -framedrop -identify -vo ";
+    String cmdline (path);
+    cmdline += " -nofs -slave -framedrop -identify -vo ";
     char buf[128];
     //if (has_xv)
     //    snprintf (buf, sizeof(buf), "xv -wid %u ", m_viewer);
     //else
         snprintf (buf, sizeof(buf),
-                has_xv
-                ? "xv,nokia770:fb_overlay_only:x=%d:y=%d:w=%d:h=%d"
-                : "omapfb,xv,nokia770:fb_overlay_only:x=%d:y=%d:w=%d:h=%d",
+                video_driver
+                ?  video_driver
+                : has_xv
+                    ? "xv,nokia770:fb_overlay_only:x=%d:y=%d:w=%d:h=%d"
+                    : "omapfb,xv,nokia770:fb_overlay_only:x=%d:y=%d:w=%d:h=%d",
                 m_rect.x() - (m_rect.x() % 2),
                 m_rect.y() - (m_rect.y() % 2),
                 m_rect.width() - (m_rect.width() % 4),
                 m_rect.height() - (m_rect.height() % 4));
     cmdline += String (buf);
+    if (audio_driver) {
+        snprintf (buf, sizeof (buf), " -ao %s", audio_driver);
+        cmdline += String (buf);
+    }
     snprintf (buf, sizeof(buf), " -wid %u ", m_viewer);
     cmdline += String (buf);
     Mrl *mrl = this->mrl ();
     if (mrl->repeat > 0)
         cmdline += String (" -loop ") + String::number (mrl->repeat);
     if (is_local_file && mrl->clip_begin > 100)
-        cmdline += String (" -ss ") + String::number (mrl->clip_begin/100);
+        cmdline += String (" -ss ") + String::number ((int) mrl->clip_begin/100);
     cmdline += Char (' ');
 
     const TrieString aspect_ratio ("aspectRatio");
@@ -446,7 +456,7 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     for (Node *n = mrl; n && !found_attr; n = n->parentNode ()) {
         if (n->id != id_node_group_node && n->id != id_node_playlist_item)
             continue;
-        Attribute *a = static_cast <Element *> (n)->attributes ()->first ();
+        Attribute *a = static_cast <Element *> (n)->attributes ().first ();
         for (; a; a = a->nextSibling ()) {
             if (aspect_ratio == a->name ()) {
                 String asp = a->value ();
@@ -1528,7 +1538,7 @@ KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
                             strdup ((const char *) e->getAttribute (KMPlayer::StringPool::attr_value)));
             } else*/ if (n->id == KMPlayer::id_node_html_embed) {
                 KMPlayer::Element *e = static_cast <KMPlayer::Element *> (n);
-                Attribute *a = e->attributes ()->first ();
+                Attribute *a = e->attributes ().first ();
                 for (; a; a = a->nextSibling ()) {
                     String nm = a->name().toString();
                     if (!g_tree_lookup (params, (const char *) nm))
