@@ -306,6 +306,7 @@ public:
     GLibString stripWhiteSpace () const;
     static GLibString fill (Char ch, int length);
     static GLibString number (int nr);
+    static GLibString number (double nr);
     bool startsWith (const GLibString & prefix) const;
     bool endsWith (const GLibString & suffix) const;
     int indexOf (const GLibString & needle) const;
@@ -1019,6 +1020,12 @@ KMPLAYER_NO_EXPORT inline GLibString GLibString::number (int nr) {
     return str;
 }
 
+KMPLAYER_NO_EXPORT inline GLibString GLibString::number (double nr) {
+    GLibString str;
+    str.takeUtf8 (g_strdup_printf ("%f", nr));
+    return str;
+}
+
 KMPLAYER_NO_EXPORT inline bool GLibString::isEmpty () const {
     return !data || !data->ptr [0];
 }
