@@ -31,7 +31,6 @@ namespace KMPlayer {
 
 class View;
 class ViewAreaPrivate;
-class RepaintUpdater;
 
 /*
  * The area in which the video widget and controlpanel are laid out
@@ -47,8 +46,7 @@ public:
     void setAudioVideoNode (NodePtr n);
     void setEventFiltering (Application *app, bool on);
     void scheduleRepaint (const IRect &rect);
-    void addUpdater (Node *node);
-    void removeUpdater (Node *node);
+    ConnectionList *updaters ();
     void resizeEvent ();
     void deleteEvent ();
     void enableUpdaters (bool enable, unsigned int off_time);
@@ -77,7 +75,7 @@ private:
     void updateSurfaceBounds ();
     bool scheduleRepaintTimeout (unsigned int cur_time);
     ViewAreaPrivate *d;
-    RepaintUpdater *m_updaters;
+    ConnectionList m_updaters;
     IRect m_av_geometry;
     float aspect;
     IRect m_repaint_rect;
